@@ -20,7 +20,7 @@ use constant MAX_COMPRESS => 9;
 
 use GD;
 
-$VERSION = '1.45';
+$VERSION = '1.48';
 $methTTF = $GD::VERSION >= 1.31 ? 'stringFT' : 'stringTTF'; # define the tff drawing method.
 
 sub init {
@@ -55,9 +55,7 @@ sub out {
       push @args, MAX_COMPRESS     if $type eq 'png' and not $self->{DISABLED}{_png_compression};
       push @args, $opt{'compress'} if $type eq 'jpeg';
    }
-   my @all_random = @{ $self->{_RND_LIST_} };
-      @all_random = ($self->{_RANDOM_NUMBER_}) unless @all_random;
-   return $self->{image}->$type(@args), $type, @all_random;
+   return $self->{image}->$type(@args), $type, $self->{_RANDOM_NUMBER_};
 }
 
 sub gdbox_empty {shift->{GDBOX_EMPTY}}
@@ -143,7 +141,14 @@ sub insert_text {
             $x = ($self->{width}  - ($box[LOW_RIGHT_X] - $box[LOW_LEFT_X])) / 2;
             $y = ($self->{height} - ($box[UP_LEFT_Y]   - $box[LOW_LEFT_Y])) / 2;
          }
-         $self->{image}->$methTTF($self->{_COLOR_}{text}, $self->{font}, $self->{ptsize}, 0, $x, $y, $key);
+         # this needs a fix. adjust x,y
+         if ($self->{angle}) {
+            require Math::Trig;
+            $self->{angle} = Math::Trig::deg2rad($self->{angle});
+         } else {
+            $self->{angle} = 0;
+         }
+         $self->{image}->$methTTF($self->{_COLOR_}{text}, $self->{font}, $self->{ptsize}, $self->{angle}, $x, $y, $key);
       }
    } else {
       if ($self->{scramble}) {
@@ -213,6 +218,12 @@ sub ttf_info {
    my $x     = 0;
    my $y     = 0;
    my @box   = GD::Image->$methTTF($self->{_COLOR_}{text},$self->{font}, $self->{ptsize},Math::Trig::deg2rad($angle),0,0,$text);
+   unless (@box) { # use fake values instead of die-ing
+      $self->{GDBOX_EMPTY} = 1; # set this for error checking.
+      $#box    = 7;
+      # lets initialize to silence the warnings
+      $box[$_] = 1 for 0..$#box;
+   }
    my $bx    = $box[LOW_LEFT_X] - $box[LOW_RIGHT_X];
    my $by    = $box[LOW_LEFT_Y] - $box[LOW_RIGHT_Y];
 
